%define anolis_release 1

Summary: SELinux binary policy manipulation library
Name: libsepol
Version: 3.5
Release: %{anolis_release}%{?dist}
License: LGPLv2+
URL: https://github.com/SELinuxProject/selinux/wiki
Source0: https://github.com/SELinuxProject/selinux/releases/download/%{version}/%{name}-%{version}.tar.gz

BuildRequires: make
BuildRequires: gcc
BuildRequires: flex
Obsoletes: %{name}-compat = 3.1

%description
Security-enhanced Linux is a feature of the Linux® kernel and a number
of utilities with enhanced security functionality designed to add
mandatory access controls to Linux.  The Security-enhanced Linux
kernel contains new architectural components originally developed to
improve the security of the Flask operating system. These
architectural components provide general support for the enforcement
of many kinds of mandatory access control policies, including those
based on the concepts of Type Enforcement®, Role-based Access
Control, and Multi-level Security.

libsepol provides an API for the manipulation of SELinux binary policies.
It is used by checkpolicy (the policy compiler) and similar tools, as well
as by programs like load_policy that need to perform specific transformations
on binary policies such as customizing policy boolean settings.

%package devel
Summary: Header files and libraries used to build policy manipulation tools
Requires: %{name} = %{version}-%{release}

%description devel
The libsepol-devel package contains the libraries and header files
needed for developing applications that manipulate binary policies. 

%package static
Summary: static libraries used to build policy manipulation tools
Requires: %{name}-devel = %{version}-%{release}

%description static
The libsepol-static package contains the static libraries and header files
needed for developing applications that manipulate binary policies. 

%package utils
Summary: SELinux libsepol utilities
Requires: %{name} = %{version}-%{release}

%description utils
The libsepol-utils package contains the utilities

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p 2 -n libsepol-%{version}


%build
%set_build_flags
CFLAGS="$CFLAGS -fno-semantic-interposition"
%make_build  LIBDIR="%{_libdir}"

%install
mkdir -p ${RPM_BUILD_ROOT}%{_libdir} 
mkdir -p ${RPM_BUILD_ROOT}%{_includedir} 
mkdir -p ${RPM_BUILD_ROOT}%{_bindir} 
mkdir -p ${RPM_BUILD_ROOT}%{_mandir}/man3
mkdir -p ${RPM_BUILD_ROOT}%{_mandir}/man8
%make_install LIBDIR="%{_libdir}" SHLIBDIR="%{_libdir}"
rm -rf ${RPM_BUILD_ROOT}%{_mandir}/man8/gen*
rm -rf ${RPM_BUILD_ROOT}%{_mandir}/ru/man8

%generate_compatibility_deps

%files static
%{_libdir}/libsepol.a

%files devel
%{_libdir}/libsepol.so
%{_libdir}/pkgconfig/libsepol.pc
%{_includedir}/sepol/*.h
%{_mandir}/man3/*.3.*
%dir %{_includedir}/sepol
%dir %{_includedir}/sepol/policydb
%{_includedir}/sepol/policydb/*.h
%dir %{_includedir}/sepol/cil
%{_includedir}/sepol/cil/*.h

%files
%dir %{abidir}
%license LICENSE
%{_libdir}/libsepol.so.2
%{abidir}/libsepol.dump

%files utils
%{_bindir}/chkcon
%{_bindir}/sepol_check_access
%{_bindir}/sepol_compute_av
%{_bindir}/sepol_compute_member
%{_bindir}/sepol_compute_relabel
%{_bindir}/sepol_validate_transition
%{_mandir}/man8/chkcon.8.*

%files doc
%doc VERSION

%changelog
* Sat Feb 25 2023 Funda Wang <fundawang@yeah.net> - 3.5-1
- New version 3.5

* Mon Jan 09 2023 yuanhui <yuanhui@linux.alibaba.com> - 3.4-3
- add doc package

* Thu Oct 20 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.4-2
- optimise spec file

* Tue Sep 27 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.4-1
- update to 3.4

* Tue Mar 08 2022 Hongwei Qin <qhw01063182@alibaba-inc.com> - 3.3-1
- SELinux userspace 3.3 release
- Init for Anolis OS 23
